@@ -72,6 +72,7 @@ class ChatTab(QWidget):
         else:
             # delay join until tab init has finished and it's been added to the tabwidget
             self.room = room
+            self.rooms_by_id = {room["id"]: room}
             QTimer.singleShot(100, self.join_room)
 
     def get_room_list(self):
@@ -215,7 +216,7 @@ class ChatTab(QWidget):
             "action":"enter",
             "name":self.server.username,
             "pass":self.server.password,
-            "room":room_id,
+            "room":self.room_id,
             "ts":str(time())}))
         self.room_join_request.error.connect(self.enter_failed)
         self.room_join_request.finished.connect(self.do_enter)
